<?php

namespace Tricks\LaravelTools\Http\Middleware;

use Illuminate\Http\Request;

class RobotsMiddleware extends \Spatie\RobotsMiddleware\RobotsMiddleware
{
    protected function shouldIndex(Request $request): bool
    {
        return false;
    }
}
